@@ -32,7 +32,7 @@ use Git::PurePerl::Protocol;
 use IO::Digest;
 use IO::Socket::INET;
 use Path::Class;
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 has 'directory' =>
     ( is => 'ro', isa => 'Path::Class::Dir', required => 1, coerce => 1 );
@@ -52,6 +52,16 @@ has 'packs' => (
     lazy_build => 1,
 );
 
+has 'description' => (
+    is      => 'rw',
+    isa     => 'Str',
+    lazy    => 1,
+    default => sub {
+        my $self = shift;
+        file( $self->directory, '.git', 'description' )->slurp( chomp => 1 );
+    }
+);
+
 __PACKAGE__->meta->make_immutable;
 
 sub BUILD {
