@@ -4,6 +4,8 @@ use MooseX::StrictConstructor;
 use Moose::Util::TypeConstraints;
 extends 'Git::PurePerl::Object';
 
+has 'kind' =>
+    ( is => 'ro', isa => 'ObjectKind', required => 1, default => 'tag' );
 has 'object'  => ( is => 'rw', isa => 'Str', required => 0 );
 has 'tag'     => ( is => 'rw', isa => 'Str', required => 0 );
 has 'tagger'  => ( is => 'rw', isa => 'Str', required => 0 );
